==> gatsby-remark-codesandbox-1.2.21.tgz: package/index.js <==
'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var visit = require(`unist-util-visit`);
var path = require('path');
var fs = require('fs');

var generateCodeSandboxUrl = require('./get-codesandbox-url').default;

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? `language-` : _ref2$classPrefix;

  visit(markdownAST, `paragraph`, function (paragraph) {
    var validParapgraph = paragraph.children.length === 1 && paragraph.children[0].type === 'link';

    if (!validParapgraph) {
      return;
    }

    var node = paragraph.children[0];

    if (!node.url.startsWith('source:')) {
      return;
    }

    var _node$url$replace$spl = node.url.replace('source:', '').split(/(?={.*})/),
        _node$url$replace$spl2 = _slicedToArray(_node$url$replace$spl, 2),
        sourcePath = _node$url$replace$spl2[0],
        _node$url$replace$spl3 = _node$url$replace$spl2[1],
        options = _node$url$replace$spl3 === undefined ? '' : _node$url$replace$spl3;

    var _options$split = options.split('?'),
        _options$split2 = _slicedToArray(_options$split, 2),
        _options$split2$ = _options$split2[0],
        highlights = _options$split2$ === undefined ? '' : _options$split2$,
        _options$split2$2 = _options$split2[1],
        codesandboxOptions = _options$split2$2 === undefined ? '' : _options$split2$2;

    var absoluteSourcePath = path.join(process.cwd(), sourcePath);

    if (!fs.existsSync(absoluteSourcePath)) {
      throw new Error(`Cannot find source in ${absoluteSourcePath}`);
    }

    var sourceCode = fs.readFileSync(absoluteSourcePath).toString().trim();

    var lineHighlightsMatch = highlights.match(/{(.*)}/);
    var highlightedLines = lineHighlightsMatch && lineHighlightsMatch[1];

    var codeSandboxUrl = generateCodeSandboxUrl(sourcePath, (codesandboxOptions ? `&${codesandboxOptions}` : '') + (highlightedLines ? `&highlights=${highlightedLines}` : ''));

    node.url = codeSandboxUrl;

    paragraph.children.unshift({
      type: 'code',
      lang: path.extname(sourcePath).slice(1) + highlights,
      value: sourceCode
    });
  });
};

==> gatsby-remark-codesandbox-1.2.22.tgz: package/index.js <==
'use strict';

var _matchers = require('./matchers');

var visit = require(`unist-util-visit`);
var path = require('path');
var fs = require('fs');

var generateCodeSandboxUrl = require('./get-codesandbox-url').default;

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? `language-` : _ref2$classPrefix;

  visit(markdownAST, `paragraph`, function (paragraph) {
    var validParapgraph = paragraph.children.length === 1 && paragraph.children[0].type === 'link';

    if (!validParapgraph) {
      return;
    }

    var node = paragraph.children[0];

    if (!node.url.startsWith('source:')) {
      return;
    }

    var sourcePath = (0, _matchers.getSourcePath)(node.url);
    var highlights = (0, _matchers.getHighlights)(node.url) || '';
    var codesandboxOptions = (0, _matchers.getOptions)(node.url) || '';

    var absoluteSourcePath = path.join(process.cwd(), sourcePath);

    if (!fs.existsSync(absoluteSourcePath)) {
      throw new Error(`Cannot find source in ${absoluteSourcePath}`);
    }

    var sourceCode = fs.readFileSync(absoluteSourcePath).toString().trim();

    var codeSandboxUrl = generateCodeSandboxUrl(sourcePath, (codesandboxOptions ? `&${codesandboxOptions}` : '') + (highlights ? `&highlights=${highlights}` : ''));

    node.url = codeSandboxUrl;

    paragraph.children.unshift({
      type: 'code',
      lang: path.extname(sourcePath).slice(1) + highlights,
      value: sourceCode
    });
  });
};
